@@ -11,10 +11,9 @@ import (
 	"encoding/json"
 	"encoding/pem"
 	"io"
-	"io/ioutil"
 	"os"
 
-	ssv1alpha1 "github.com/bitnami-labs/sealed-secrets/pkg/apis/sealed-secrets/v1alpha1"
+	ssv1alpha1 "github.com/bitnami-labs/sealed-secrets/pkg/apis/sealedsecrets/v1alpha1"
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/gomega"
 	v1 "k8s.io/api/core/v1"
@@ -55,7 +54,7 @@ var _ = Describe("kubeseal", func() {
 	})
 
 	JustBeforeEach(func() {
-		f, err := ioutil.TempFile("", "kubeconfig")
+		f, err := os.CreateTemp("", "kubeconfig")
 		Expect(err).NotTo(HaveOccurred())
 
 		buf, err := runtime.Encode(clientcmdlatest.Codec, config)
@@ -165,7 +164,7 @@ var _ = Describe("kubeseal", func() {
 
 		BeforeEach(func() {
 			var err error
-			certfile, err = ioutil.TempFile("", "kubeseal-test")
+			certfile, err = os.CreateTemp("", "kubeseal-test")
 			Expect(err).NotTo(HaveOccurred())
 
 			for _, cert := range certs {
@@ -313,7 +312,7 @@ var _ = Describe("kubeseal --cert", func() {
 	})
 
 	JustBeforeEach(func() {
-		err := runKubeseal(args, input, ioutil.Discard, runAppWithStderr(output))
+		err := runKubeseal(args, input, io.Discard, runAppWithStderr(output))
 		Expect(err).To(HaveOccurred())
 	})
 
@@ -361,16 +360,16 @@ var _ = Describe("kubeseal --recovery-unseal", func() {
 		Expect(err).NotTo(HaveOccurred())
 	})
 	BeforeEach(func() {
-		master, err := c.Secrets("kube-system").List(ctx, metav1.ListOptions{
+		key, err := c.Secrets("kube-system").List(ctx, metav1.ListOptions{
 			LabelSelector: keySelector,
 		})
 		Expect(err).NotTo(HaveOccurred())
 
-		backupKeysFile, err = ioutil.TempFile("", "master")
+		backupKeysFile, err = os.CreateTemp("", "key")
 		Expect(err).NotTo(HaveOccurred())
 		defer backupKeysFile.Close()
 
-		json, err := json.Marshal(master)
+		json, err := json.Marshal(key)
 		Expect(err).NotTo(HaveOccurred())
 
 		backupKeysFile.Write(json)
